package Task::BeLike::BINGOS;

use strict;
use warnings;
use vars qw($VERSION);

$VERSION = '1.00';

'Looks like I picked the wrong week to quit sniffing glue.';

__END__

=head1 NAME

Task::BeLike::BINGOS - Be the most BINGOS you can be

=head1 DESCRIPTION

Task::BeLike::BINGOS is a L<Task> module to install all the modules that I like to have
kicking around.

See the C<Makefile.PL> file in this distribution for details.

=head1 AUTHOR

Chris C<BinGOs> Williams <chris@bingosnet.co.uk>

=head1 LICENSE

Copyright E<copy> Chris Williams

This module may be used, modified, and distributed under the same terms as Perl itself. Please see the license that came with your Perl distribution for details.

=cut
